pub enum OnLanguageFailure {
ChangeVoice,
IgnoreText,
IgnoreLang,
ProcessorChoice,
}Expand description
The onlangfailure attribute is an optional attribute that contains one value from the following enumerated list describing the desired behavior of the synthesis processor upon language speaking failure. A conforming synthesis processor must report a language speaking failure in addition to taking th action(s) below.
“Speech Synthesis Markup Language (SSML) Version 1.1” Copyright © 2010 W3C® (MIT, ERCIM, Keio), All Rights Reserved.
Variants
ChangeVoice
If a voice exists that can speak the language, the synthesis processor will switch to that voice and speak the content. Otherwise, the processor chooses another behavior (either ignoretext or ignorelang).
IgnoreText
The synthesis processor will not attempt to render the text that is in the failed language.
IgnoreLang
The synthesis processor will ignore the change in language and speak as if the content were in the previous language.
ProcessorChoice
The synthesis processor chooses the behavior (either changevoice, ignoretext, or ignorelang).