pub enum SsmlElement {
Show 21 variants
Speak,
Lexicon,
Lookup,
Meta,
Metadata,
Paragraph,
Sentence,
Token,
Word,
SayAs,
Phoneme,
Sub,
Lang,
Voice,
Emphasis,
Break,
Prosody,
Audio,
Mark,
Description,
Custom(String),
}Expand description
Type of the SSML element
Variants
Speak
The <speak></speak> element.
Lexicon
The <lexicon/> element.
Lookup
The <lookup></lookup> element.
Meta
The <meta/> element.
Metadata
The <metadata></metadata> element.
Paragraph
The <p></p> element.
Sentence
The <s></s> element.
Token
The <token></token> element.
Word
The <word></word> element.
SayAs
The <say-as></say-as> element.
Phoneme
The <phoneme></phoneme> element.
Sub
The <sub></sub> element.
Lang
The <lang></lang> element.
Voice
The <voice></voice> element.
Emphasis
The <emphasis></emphasis> element.
Break
The <break/> element.
Prosody
The <prosody></prosody> element.
Audio
The <audio></audio> element.
Mark
The <mark/> element.
Description
The <desc></desc> element.
Custom(String)
Custom elements not defined in the spec, the element name is stored in the given string.
Implementations
Sourceimpl SsmlElement
impl SsmlElement
Returns whether a tag can contain other tags - will always be true for custom tags as we want to check just in case.
Sourcepub fn can_contain(&self, other: &Self) -> bool
pub fn can_contain(&self, other: &Self) -> bool
Check whether the provided element can contain another specified tag. For custom elements if an element can contain tags it will be assumed it can contain the custom one as these are outside of the SSML specification.